<?php
namespace MascotCoreLovebite\Widgets\ServiceBlock\Skins;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Skin_Base as Elementor_Skin_Base;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class Skin_Style3 extends Elementor_Skin_Base {

	protected function _register_controls_actions() {
		add_action( 'elementor/element/tm-ele-service-block/tm_general/after_section_end', [ $this, 'register_layout_controls' ] );
	}

	public function get_id() {
		return 'skin-style3';
	}


	public function get_title() {
		return __( 'Skin Style3', 'mascot-core-lovebite' );
	}


	public function register_layout_controls( Widget_Base $widget ) {
		$this->parent = $widget;


		$this->start_controls_section(
			'current_skin_bg_styling',
			[
				'label' => esc_html__( 'Current Skin Styling', 'mascot-core-lovebite' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'current_skin_bg_color_options',
			[
				'label' => esc_html__( 'BG Color Options', 'mascot-core-lovebite' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$this->start_controls_tabs('tabs_current_theme_styling');
		$this->start_controls_tab(
			'tabs_current_theme_styling_normal',
			[
				'label' => esc_html__('Normal', 'mascot-core-lovebite'),
			]
		);
		$this->add_responsive_control(
			'current_skin_bg_custom_bg_color',
			[
				'label' => esc_html__( "Custom Background Color", 'mascot-core-lovebite' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .service-block-style3 .inner-box .content-box' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .service-block-style3 .inner-box .content-box::before' => 'background-color: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'current_skin_bg_theme_colored',
			[
				'label' => esc_html__( "Custom Border Color", 'mascot-core-lovebite' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .service-block-style3 .inner-box .content-box::after' => 'border-color: {{VALUE}};'
				],
			]
		);

		$this->add_control(
			'current_skin_icon_bg_color_options',
			[
				'label' => esc_html__( 'Icon Options', 'mascot-core-lovebite' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);

		$this->add_responsive_control(
			'current_skin_bg_custom_icon_bg_color',
			[
				'label' => esc_html__( "Custom Icon BG Color", 'mascot-core-lovebite' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .service-block-style3 .service-icon' => 'background-color: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'current_skin_icon_bg_theme_colored',
			[
				'label' => esc_html__( "Make Icon BG Theme Colored", 'mascot-core-lovebite' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_lovebite_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .service-block-style3 .service-icon' => 'background-color: var(--theme-color{{VALUE}});'
				],
			]
		);

		$this->add_responsive_control(
			'current_skin_bg_custom_icon_text_bg_color',
			[
				'label' => esc_html__( "Custom Icon Color Color", 'mascot-core-lovebite' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .service-block-style3 .service-icon' => 'color: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'current_skin_icon_text_bg_theme_colored',
			[
				'label' => esc_html__( "Make Icon Color Theme Colored", 'mascot-core-lovebite' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_lovebite_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .service-block-style3 .service-icon' => 'color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->end_controls_tab();

		$this->start_controls_tab(
			'tabs_current_theme_styling_hover',
			[
				'label' => esc_html__('Hover', 'mascot-core-lovebite'),
			]
		);

		$this->add_control(
			'current_skin_bg_color_bg_options',
			[
				'label' => esc_html__( 'BG Color Options ( Hover )', 'mascot-core-lovebite' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);
		$this->add_responsive_control(
			'current_skin_bg_hover_custom_bg_color',
			[
				'label' => esc_html__( "Custom Background Color", 'mascot-core-lovebite' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .service-block-style3:hover .inner-box .content-box' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .service-block-style3:hover .inner-box .content-box::before' => 'background-color: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'current_skin_bg_hover_theme_colored',
			[
				'label' => esc_html__( "Custom Border Color", 'mascot-core-lovebite' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .service-block-style3:hover .inner-box .content-box::after' => 'border-color: {{VALUE}};'
				],
			]
		);


		$this->add_control(
			'current_skin_hover_icon_bg_color_options',
			[
				'label' => esc_html__( 'Icon Options ( Hover )', 'mascot-core-lovebite' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);

		$this->add_responsive_control(
			'current_skin_hover_bg_custom_icon_bg_color',
			[
				'label' => esc_html__( "Custom Icon BG Color", 'mascot-core-lovebite' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .service-block-style3:hover .service-icon' => 'background-color: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'current_skin_hover_icon_bg_theme_colored',
			[
				'label' => esc_html__( "Make Icon BG Theme Colored", 'mascot-core-lovebite' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_lovebite_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .service-block-style3:hover .service-icon' => 'background-color: var(--theme-color{{VALUE}});'
				],
			]
		);

		$this->add_responsive_control(
			'current_skin_hover_bg_custom_icon_text_bg_color',
			[
				'label' => esc_html__( "Custom Icon Color Color", 'mascot-core-lovebite' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .service-block-style3:hover .service-icon' => 'color: {{VALUE}};'
				]
			]
		);
		$this->add_responsive_control(
			'current_skin_hover_icon_text_bg_theme_colored',
			[
				'label' => esc_html__( "Make Icon Color Theme Colored", 'mascot-core-lovebite' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_lovebite_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .service-block-style3:hover .service-icon' => 'color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->end_controls_section();

	}

	public function render() {
		$settings = $this->parent->get_settings_for_display();


		if( $settings['animate_icon_on_hover'] ) {
			$classes[] = 'animate-icon-on-hover animate-icon-'.$settings['animate_icon_on_hover'];
		}

		//icon classes
		$icon_classes = array();
		$settings['icon_classes'] = $icon_classes;

		//button classes
		$settings['btn_classes'] = mascot_core_lovebite_prepare_button_classes_from_params( $settings );


		//icon classes
		$icon_classes = array();
		$settings['icon_classes'] = $icon_classes;

		//Owl Carousel Data
		$settings['owl_carousel_data_info'] = mascot_core_lovebite_prepare_owlcarousel_data_from_params( $settings );
		$settings['holder_id'] = lovebite_get_isotope_holder_ID('service-block');

		$settings['settings'] = $settings;

		//Produce HTML version by using the parameters (filename, variation, folder name, parameters, shortcode_ob_start)
		$html = mascot_core_lovebite_get_shortcode_template_part( 'service', $settings['display_type'], 'service-block/tpl', $settings, true );

		echo $html;
	}
}